FirebirdDA
==============

FirebirdDA is Zope database adapter for Interbase/Firebird.  

Installation
-----------------

buildout.cfg::

   eggs =
       ...
       firebirdsql
       Products.FirebirdDA

